@@ -10,20 +10,22 @@ from allauth.socialaccount.providers.oauth2.views import (
     OAuth2LoginView,
 )
 
-from .provider import API_URL, USE_API_V2, PatreonProvider
+from .constants import API_URL, PROVIDER_ID, USE_API_V2
 
 
 class PatreonOAuth2Adapter(OAuth2Adapter):
-    provider_id = PatreonProvider.id
-    access_token_url = "https://www.patreon.com/api/oauth2/token"
+    provider_id = PROVIDER_ID
+    access_token_url = "https://www.patreon.com/api/oauth2/token"  # nosec
     authorize_url = "https://www.patreon.com/oauth2/authorize"
     profile_url = "{0}/{1}".format(
         API_URL,
-        "identity?include=memberships&fields%5Buser%5D=email,first_name,"
-        "full_name,image_url,last_name,social_connections,"
-        "thumb_url,url,vanity"
-        if USE_API_V2
-        else "current_user",
+        (
+            "identity?include=memberships&fields%5Buser%5D=email,first_name,"
+            "full_name,image_url,last_name,social_connections,"
+            "thumb_url,url,vanity"
+            if USE_API_V2
+            else "current_user"
+        ),
     )
 
     def complete_login(self, request, app, token, **kwargs):
